describe('ZhLayoutWidgetsBuilder', function(){

    var restEngine;
    var templateManager;
    var metaDataFactory;
    var zhLayoutWidgetsBuilder;

    beforeEach(function(){
        templateManager = {
            'container': {
                'id': 1,
                'name': 'container'
            }
        };

        restEngine      = jasmine.createSpyObj('RestEngine',      ['requestMetaData']);
        metaDataFactory = jasmine.createSpyObj('MetaDataFactory', ['widgetFactory']);
        zhLayoutWidgetsBuilder = new ZhLayoutWidgetsBuilder(restEngine, templateManager, metaDataFactory);
    });

    it('factoryWidget', function(done){
        var widgetName = 'widget-name';

        restEngine.requestMetaData.and.callFake(function(){
            return Q.when({
                'data': '{"name": "widget"}'
            });
        });

        var factoryWidget = {'name': 'widget'};

        metaDataFactory.widgetFactory.and.callFake(function(){
            return Q.when(factoryWidget);
        });

        zhLayoutWidgetsBuilder.factoryWidget(widgetName).then(function(factoryWidget){
            expect(restEngine.requestMetaData).toHaveBeenCalledWith('zh-layout-preferences#json/widgets/widget-name.json');
            expect(metaDataFactory.widgetFactory).toHaveBeenCalledWith('{"name": "widget"}', templateManager.container);
            done();
        });
    });

    it('factoryLayoutConfigurationWidget', function(){
        spyOn(zhLayoutWidgetsBuilder, 'factoryWidget');
        zhLayoutWidgetsBuilder.factoryLayoutConfigurationWidget();
        expect(zhLayoutWidgetsBuilder.factoryWidget).toHaveBeenCalledWith('config');
    });

    it('factoryCreateLayoutWidget', function(){
        spyOn(zhLayoutWidgetsBuilder, 'factoryWidget');
        zhLayoutWidgetsBuilder.factoryCreateLayoutWidget();
        expect(zhLayoutWidgetsBuilder.factoryWidget).toHaveBeenCalledWith('createLayout');
    });

    it('factoryBuildLayoutOptionsWidget', function(){
        spyOn(zhLayoutWidgetsBuilder, 'factoryWidget');
        zhLayoutWidgetsBuilder.factoryBuildLayoutOptionsWidget();
        expect(zhLayoutWidgetsBuilder.factoryWidget).toHaveBeenCalledWith('createLayoutOptions');
    });

    it('factoryImportLayoutWidget', function(){
        spyOn(zhLayoutWidgetsBuilder, 'factoryWidget');
        zhLayoutWidgetsBuilder.factoryImportLayoutWidget();
        expect(zhLayoutWidgetsBuilder.factoryWidget).toHaveBeenCalledWith('importLayout');
    });

    it('factoryBuildLayoutFieldOptionsWidget', function(){
        spyOn(zhLayoutWidgetsBuilder, 'factoryWidget');
        zhLayoutWidgetsBuilder.factoryBuildLayoutFieldOptionsWidget();
        expect(zhLayoutWidgetsBuilder.factoryWidget).toHaveBeenCalledWith('createLayoutFieldOptions');
    });

});